@@ -38,8 +38,6 @@ from ..pagination import TypeaheadPagination
 from ..utils import get_organization_model, get_user_serializer
 
 
-#pylint: disable=no-init
-
 def get_order_func(fields):
     """
     Builds a lambda function that can be used to order two records
@@ -51,18 +49,22 @@ def get_order_func(fields):
         if fields[0].startswith('-'):
             field_name = fields[0][1:]
             return lambda left, right: (
-                getattr(left, field_name) > getattr(right, field_name))
+                (getattr(left, field_name) and getattr(right, field_name) and
+                getattr(left, field_name) > getattr(right, field_name)))
         field_name = fields[0]
         return lambda left, right: (
-            getattr(left, field_name) < getattr(right, field_name))
+            (getattr(left, field_name) and getattr(right, field_name) and
+            getattr(left, field_name) < getattr(right, field_name)))
     if fields[0].startswith('-'):
         field_name = fields[0][1:]
         return lambda left, right: (
-            getattr(left, field_name) > getattr(right, field_name) or
+            (getattr(left, field_name) and getattr(right, field_name) and
+            getattr(left, field_name) > getattr(right, field_name)) or
             get_order_func(fields[1:])(left, right))
     field_name = fields[0]
     return lambda left, right: (
-        getattr(left, field_name) < getattr(right, field_name) or
+        (getattr(left, field_name) and getattr(right, field_name) and
+        getattr(left, field_name) < getattr(right, field_name)) or
         get_order_func(fields[1:])(left, right))
 
 
@@ -86,7 +88,7 @@ class AccountsTypeaheadAPIView(OrganizationSmartListMixin,
 
     The API is typically used in pages for the support team to quickly
     locate an account. For example, it is used within the HTML
-    `provider dashboard page </docs/themes/#dashboard_metrics_dashboard>`_
+    `provider dashboard page </docs/guides/themes/#dashboard_metrics_dashboard>`_
     as present in the default theme.
 
     **Tags**: list, profile, user
@@ -218,7 +220,7 @@ class ProfilesTypeaheadAPIView(OrganizationSmartListMixin,
     ([``start_at``, ``ends_at``]), and sorted on specific fields (``o``).
 
     The API is typically used within an HTML
-    `connected profiles page </docs/themes/#dashboard_users_roles>`_
+    `connected profiles page </docs/guides/themes/#dashboard_users_roles>`_
     as present in the default theme.
 
     **Tags**: list, profile, user
@@ -327,7 +329,7 @@ class ProfileAPIView(OrganizationMixin, OrganizationDecorateMixin,
     Retrieves a billing profile
 
     The API is typically used within an HTML
-    `contact information page </docs/themes/#dashboard_profile>`_
+    `contact information page </docs/guides/themes/#dashboard_profile>`_
     as present in the default theme.
 
     **Tags**: profile, subscriber, profilemodel
@@ -347,7 +349,7 @@ class ProfileAPIView(OrganizationMixin, OrganizationDecorateMixin,
             "printable_name": "Xia Lee",
             "picture": null,
             "type": "organization",
-            "crednetials": true
+            "credentials": true
         }
     """
     lookup_field = 'slug'
@@ -391,7 +393,7 @@ class UsersTypeaheadAPIView(UserSmartListMixin, UserQuerysetMixin,
     ([``start_at``, ``ends_at``]), and sorted on specific fields (``o``).
 
     The API is typically used within an HTML
-    `profile role page </docs/themes/#dashboard_profile_roles>`_
+    `profile role page </docs/guides/themes/#dashboard_profile_roles>`_
     as present in the default theme.
 
     **Tags**: list, profile, user
