@@ -39,8 +39,6 @@ from ..models import Coupon
 from ..mixins import CouponMixin, ProviderMixin
 from ..utils import handle_uniq_error
 
-#pylint: disable=no-init
-
 
 class SmartCouponListMixin(object):
     """
@@ -87,7 +85,7 @@ class CouponListCreateAPIView(SmartCouponListMixin, CouponQuerysetMixin,
     and sorted on specific fields (``o``).
 
     The API is typically used within an HTML
-    `coupons page </docs/themes/#dashboard_billing_coupons>`_
+    `coupons page </docs/guides/themes/#dashboard_billing_coupons>`_
     as present in the default theme.
 
     **Tags**: billing, list, provider, couponmodel
@@ -148,7 +146,7 @@ class CouponListCreateAPIView(SmartCouponListMixin, CouponQuerysetMixin,
         to subscribe to plans from the Coupon's provider at a discount.
 
         The API is typically used within an HTML
-        `coupons page </docs/themes/#dashboard_billing_coupons>`_
+        `coupons page </docs/guides/themes/#dashboard_billing_coupons>`_
         as present in the default theme.
 
         **Tags**: billing, provider, couponmodel
@@ -207,7 +205,7 @@ class CouponDetailAPIView(CouponMixin, RetrieveUpdateDestroyAPIView):
     Retrieves a discount code
 
     The API is typically used within an HTML
-    `coupons page </docs/themes/#dashboard_billing_coupons>`_
+    `coupons page </docs/guides/themes/#dashboard_billing_coupons>`_
     as present in the default theme.
 
     **Tags**: billing, provider, couponmodel
@@ -245,7 +243,7 @@ class CouponDetailAPIView(CouponMixin, RetrieveUpdateDestroyAPIView):
         Updates a discount code
 
         The API is typically used within an HTML
-        `coupons page </docs/themes/#dashboard_billing_coupons>`_
+        `coupons page </docs/guides/themes/#dashboard_billing_coupons>`_
         as present in the default theme.
 
         **Tags**: billing, provider, couponmodel
@@ -290,6 +288,7 @@ class CouponDetailAPIView(CouponMixin, RetrieveUpdateDestroyAPIView):
         if getattr(instance, '_prefetched_objects_cache', None):
             # If 'prefetch_related' has been applied to a queryset, we need to
             # forcibly invalidate the prefetch cache on the instance.
+            #pylint:disable=protected-access
             instance._prefetched_objects_cache = {}
 
         return Response(CouponSerializer().to_representation(
@@ -305,7 +304,7 @@ class CouponDetailAPIView(CouponMixin, RetrieveUpdateDestroyAPIView):
         performance measurements.
 
         The API is typically used within an HTML
-        `coupons page </docs/themes/#dashboard_billing_coupons>`_
+        `coupons page </docs/guides/themes/#dashboard_billing_coupons>`_
         as present in the default theme.
 
         **Tags**: billing, provider, couponmodel
