@@ -58,7 +58,7 @@ class OrganizationDetailAPIView(OrganizationMixin, OrganizationQuerysetMixin,
     Retrieves a billing profile
 
     The API is typically used within an HTML
-    `contact information page </docs/themes/#dashboard_profile>`_
+    `contact information page </docs/guides/themes/#dashboard_profile>`_
     as present in the default theme.
 
     **Tags**: profile, subscriber, profilemodel
@@ -94,7 +94,10 @@ class OrganizationDetailAPIView(OrganizationMixin, OrganizationQuerysetMixin,
                 {
                     "created_at": "2018-01-01T00:00:00Z",
                     "ends_at": "2019-01-01T00:00:00Z",
-                    "plan": "open-space",
+                    "plan": {
+                        "slug": "open-space",
+                        "title": "Open Space"
+                    },
                     "auto_renew": true
                 }
             ]
@@ -110,7 +113,7 @@ class OrganizationDetailAPIView(OrganizationMixin, OrganizationQuerysetMixin,
         Updates a billing profile
 
         The API is typically used within an HTML
-        `contact information page </docs/themes/#dashboard_profile>`_
+        `contact information page </docs/guides/themes/#dashboard_profile>`_
         as present in the default theme.
 
         **Tags**: profile, subscriber, profilemodel
@@ -159,7 +162,7 @@ class OrganizationDetailAPIView(OrganizationMixin, OrganizationQuerysetMixin,
         on subscriptions and transactions.
 
         The API is typically used within an HTML
-        `contact information page </docs/themes/#dashboard_profile>`_
+        `contact information page </docs/guides/themes/#dashboard_profile>`_
         as present in the default theme.
 
         **Tags**: profile, subscriber, profilemodel
@@ -354,17 +357,22 @@ class SubscribersQuerysetMixin(OrganizationDecorateMixin, ProviderMixin):
         return page
 
 
-class SubscribersAPIView(OrganizationSmartListMixin,
-                         SubscribersQuerysetMixin, ListAPIView):
+class ProviderAccessiblesAPIView(OrganizationSmartListMixin,
+                                 SubscribersQuerysetMixin, ListAPIView):
     """
-    Lists subscribers for a provider
+    Lists subscribers
 
-    Returns a list of {{PAGE_SIZE}} subscriber profiles which have or
-    had a subscription to a plan of the specified provider.
+    Returns a list of {{PAGE_SIZE}} subscribers which have or
+    had a subscription to a plan of the specified provider {profile}.
 
-    The queryset can be further refined to match a search filter (``q``)
-    and/or a range of dates ([``start_at``, ``ends_at``]),
-    and sorted on specific fields (``o``).
+    The queryset can be filtered for at least one field to match a search
+    term (``q``) and/or intersects a period (``start_at``, ``ends_at``).
+
+    Returned results can be ordered by natural fields (``o``) in either
+    ascending or descending order by using the minus sign ('-') in front
+    of the ordering field name.
+
+    The API is typically used in search forms linked to providers.
 
     **Tags**: list, provider, profilemodel, subscriptions
 
@@ -451,8 +459,8 @@ class EngagedSubscribersAPIView(EngagedSubscribersSmartListMixin,
     """
     Lists engaged subscribers
 
-    Returns a list of {{PAGE_SIZE}} subscriber profiles which have or
-    had a subscription to a plan of the specified provider.
+    Returns a list of {{PAGE_SIZE}} subscribers which have or
+    had a subscription to a plan of the specified provider {profile}.
 
     The queryset can be further refined to match a search filter (``q``)
     and/or a range of dates ([``start_at``, ``ends_at``]),
@@ -520,10 +528,13 @@ class UnengagedSubscribersQuerysetMixin(DateRangeContextMixin,
             kwargs.update({
                 'role__user__last_login__gte': ends_at - relativedelta(
                     days=settings.INACTIVITY_DAYS)})
+        one_login_within_period = get_organization_model().objects.filter(
+            **kwargs)
         queryset = get_organization_model().objects.filter(
             is_active=True,
             subscribes_to__organization=self.provider,
-            subscriptions__ends_at__gt=ends_at).exclude(**kwargs).distinct()
+            subscriptions__ends_at__gt=ends_at).exclude(
+                pk__in=one_login_within_period).distinct()
         return queryset
 
 
@@ -533,8 +544,8 @@ class UnengagedSubscribersAPIView(OrganizationSmartListMixin,
     """
     Lists inactive subscribers
 
-    Returns a list of {{PAGE_SIZE}} subscriber profiles which have or
-    had a subscription to a plan of the specified provider.
+    Returns a list of {{PAGE_SIZE}} subscribers which have or
+    had a subscription to a plan of the specified provider {profile}.
 
     The queryset can be further refined to match a search filter (``q``)
     and/or a range of dates ([``start_at``, ``ends_at``]),
@@ -568,3 +579,6 @@ class UnengagedSubscribersAPIView(OrganizationSmartListMixin,
         }
     """
     serializer_class = OrganizationSerializer
+    filter_backends = (SearchFilter, OrderingFilter) # if we don't remove
+         # the DateRangeFilter, then we will only get unengaged Organization
+         # that were created within the date range.
