@@ -126,7 +126,7 @@ class OptinBase(OrganizationDecorateMixin, OrganizationCreateMixin):
     organization_model = get_organization_model()
 
     def add_relations(self, organizations, user, ends_at=None):
-        #pylint:disable=no-self-use,unused-argument
+        #pylint:disable=unused-argument
         roles = []
         created = False
         for organization in organizations:
@@ -138,7 +138,7 @@ class OptinBase(OrganizationDecorateMixin, OrganizationCreateMixin):
         return roles, created
 
     def send_signals(self, relations, user, reason=None, invite=False):
-        #pylint:disable=no-self-use,unused-argument
+        #pylint:disable=unused-argument
         for role in relations:
             signals.role_request_created.send(sender=__name__,
                 role=role, reason=reason)
@@ -320,7 +320,7 @@ class AccessibleByListAPIView(RoleSmartListMixin, InvitedRequestedListMixin,
     and sorted on specific fields (``o``).
 
     The API is typically used within an HTML
-    `connected profiles page </docs/themes/#dashboard_users_roles>`_
+    `connected profiles page </docs/guides/themes/#dashboard_users_roles>`_
     as present in the default theme.
 
     see :doc:`Flexible Security Framework <security>`.
@@ -386,7 +386,7 @@ accessibles/manager/cowork",
         Creates a request to attach {user} to a role on a profile
 
         The API is typically used within an HTML
-        `connected profiles page </docs/themes/#dashboard_users_roles>`_
+        `connected profiles page </docs/guides/themes/#dashboard_users_roles>`_
         as present in the default theme.
 
         see :doc:`Flexible Security Framework <security>`.
@@ -451,7 +451,7 @@ class AccessibleByDescrListAPIView(RoleSmartListMixin,
     and sorted on specific fields (``o``).
 
     The API is typically used within an HTML
-    `connected profiles page </docs/themes/#dashboard_users_roles>`_
+    `connected profiles page </docs/guides/themes/#dashboard_users_roles>`_
     as present in the default theme.
 
     see :doc:`Flexible Security Framework <security>`.
@@ -518,7 +518,7 @@ accessibles/manager/cowork",
         with a specified {role}.
 
         The API is typically used within an HTML
-        `connected profiles page </docs/themes/#dashboard_users_roles>`_
+        `connected profiles page </docs/guides/themes/#dashboard_users_roles>`_
         as present in the default theme.
 
         see :doc:`Flexible Security Framework <security>`.
@@ -634,8 +634,6 @@ class RoleDescriptionListCreateView(RoleDescriptionQuerysetMixin,
             "count": 2,
             "next": null,
             "previous": null,
-            "invited_count": 0,
-            "requested_count": 0,
             "results": [
                 {
                     "created_at": "2018-01-01T00:00:00Z",
@@ -1014,7 +1012,20 @@ class RoleByDescrListAPIView(RoleSmartListMixin, RoleByDescrQuerysetMixin,
         .. code-block:: json
 
             {
-              "slug": "xia"
+                "created_at": "2018-01-01T00:00:00Z",
+                "role_description": {
+                    "created_at": "2018-01-01T00:00:00Z",
+                    "title": "Profile Manager",
+                    "slug": "manager",
+                    "is_global": true
+                },
+                "user": {
+                    "slug": "xia",
+                    "username": "xia",
+                    "printable_name": "Xia Lee",
+                    "picture": null
+                },
+                "grant_key": null
             }
         """
         return super(RoleByDescrListAPIView, self).post(
@@ -1061,7 +1072,6 @@ class RoleDetailAPIView(RoleMixin, DestroyAPIView):
                     "printable_name": "Xia Lee",
                     "picture": null
                 },
-                "request_key": "1",
                 "grant_key": null
             }
         """
@@ -1149,8 +1159,7 @@ class AccessibleDetailAPIView(RoleDetailAPIView):
                     "type": "organization",
                     "credentials": false
                 },
-                "request_key": "1",
-                "grant_key": null
+                "request_key": null
             }
         """
         role = self.get_object()
@@ -1169,7 +1178,7 @@ class AccessibleDetailAPIView(RoleDetailAPIView):
         permissions from this user to manage part of the profile.
 
         The API is typically used within an HTML
-        `connected profiles page </docs/themes/#dashboard_users_roles>`_
+        `connected profiles page </docs/guides/themes/#dashboard_users_roles>`_
         as present in the default theme.
 
         **Tags**: rbac
@@ -1196,7 +1205,7 @@ class RoleAcceptAPIView(UserMixin, GenericAPIView):
         Accepts a role identified by {verification_key}.
 
         The API is typically used within an HTML
-        `connected profiles page </docs/themes/#dashboard_users_roles>`_
+        `connected profiles page </docs/guides/themes/#dashboard_users_roles>`_
         as present in the default theme.
 
         **Tags**: rbac, user, rolemodel
@@ -1289,8 +1298,6 @@ class UserProfileListAPIView(OrganizationSmartListMixin,
             "count": 1,
             "next": null,
             "previous": null,
-            "invited_count": 0,
-            "requested_count": 0,
             "results": [
                 {
                     "created_at": "2018-01-01T00:00:00Z",
