@@ -56,9 +56,8 @@ from ..mixins import as_html_description, product_url
 from ..models import (AdvanceDiscount, BalanceLine, CartItem, Charge, Coupon,
     Plan, RoleDescription, Subscription, Transaction, get_broker)
 from ..utils import (build_absolute_uri, get_organization_model, get_role_model,
-    get_user_serializer)
+    get_user_serializer, get_user_detail_serializer)
 
-#pylint: disable=no-init
 
 LOGGER = logging.getLogger(__name__)
 
@@ -437,7 +436,8 @@ class WithEndsAtByPlanSerializer(NoModelSerializer):
 
 class WithSubscriptionSerializer(serializers.ModelSerializer):
 
-    plan = serializers.SlugRelatedField(read_only=True, slug_field='slug')
+    plan = PlanSerializer(read_only=True,
+        help_text=_("Plan the profile is subscribed to"))
 
     class Meta:
         model = Subscription
@@ -459,8 +459,10 @@ class OrganizationSerializer(serializers.ModelSerializer):
 
     class Meta:
         model = get_organization_model()
-        fields = ('slug', 'printable_name', 'picture', 'type', 'credentials')
-        read_only_fields = ('printable_name', 'type', 'credentials')
+        fields = ('slug', 'printable_name', 'picture', 'type', 'credentials',
+            'created_at')
+        read_only_fields = ('printable_name', 'type', 'credentials',
+            'created_at')
 
     @staticmethod
     def get_printable_name(obj):
@@ -483,7 +485,7 @@ class OrganizationSerializer(serializers.ModelSerializer):
         return 'organization'
 
 OrganizationSerializer._declared_fields["type"] = \
-    serializers.SerializerMethodField(#pylint:disable=protected-access
+    serializers.SerializerMethodField(#pylint:disable=protected-access,no-member
     help_text=_("One of 'organization', 'personal' or 'user'"))
 
 
@@ -541,7 +543,8 @@ class OrganizationCreateSerializer(OrganizationDetailSerializer):
         fields = OrganizationDetailSerializer.Meta.fields
 
 OrganizationCreateSerializer._declared_fields["type"] = \
-    serializers.CharField(required=False,#pylint:disable=protected-access
+    serializers.CharField(#pylint:disable=protected-access,no-member
+        required=False,
         help_text=_("One of 'organization', 'personal' or 'user'"))
 
 
@@ -550,7 +553,8 @@ class OrganizationWithSubscriptionsSerializer(OrganizationDetailSerializer):
     Operational information on an Organization,
     bundled with its subscriptions.
     """
-    subscriptions = WithSubscriptionSerializer(many=True, read_only=True)
+    subscriptions = WithSubscriptionSerializer(many=True, read_only=True,
+        help_text=_("Active subscriptions for the profile"))
 
     class Meta(OrganizationDetailSerializer.Meta):
         fields = OrganizationDetailSerializer.Meta.fields + (
@@ -771,6 +775,18 @@ class ProvidedSubscriptionSerializer(SubscriptionSerializer):
                 obj.plan.organization, obj.plan, obj.organization)))
 
 
+class ProvidedSubscriptionDetailSerializer(SubscriptionSerializer):
+    """
+    For active subscriptions we return the contact information for the profile.
+    """
+    profile = OrganizationDetailSerializer(source='organization',
+        read_only=True,
+        help_text=_("Profile subscribed to the plan"))
+
+    class Meta(SubscriptionSerializer.Meta):
+        pass
+
+
 class ProvidedSubscriptionCreateSerializer(serializers.ModelSerializer):
 
     profile = OrganizationInviteSerializer(source='organization',
@@ -855,7 +871,8 @@ class CreateOfflineTransactionSerializer(NoModelSerializer):
     created_at = serializers.DateTimeField(
         help_text=_("Date/time of creation (in ISO format)"))
     # XXX Shouldn't this be same format as TransactionSerializer.amount?
-    amount = serializers.DecimalField(None, 2)
+    amount = serializers.DecimalField(None, 2,
+        help_text=_("Total amount in currency unit"))
     descr = serializers.CharField(required=False,
         help_text=_("Free-form text description for the %(object)s") % {
             'object': 'transaction'})
@@ -917,9 +934,12 @@ class CartItemCreateSerializer(serializers.ModelSerializer):
 
 class CartItemUploadSerializer(NoModelSerializer):
 
-    created = CartItemSerializer(many=True)
-    updated = CartItemSerializer(many=True)
-    failed = CartItemSerializer(many=True)
+    created = CartItemSerializer(many=True,
+        help_text=_("Items that have been created in the cart"))
+    updated = CartItemSerializer(many=True,
+        help_text=_("Rows that have been uploaded"))
+    failed = CartItemSerializer(many=True,
+        help_text=_("Rows that have failed to be created in the cart"))
 
 
 class InvoicableSerializer(NoModelSerializer):
@@ -1021,7 +1041,7 @@ class AccessibleCreateSerializer(NoModelSerializer):
 
 class RoleSerializer(serializers.ModelSerializer):
 
-    user = get_user_serializer()(read_only=True,
+    user = get_user_detail_serializer()(read_only=True,
         help_text=_("User with the role"))
     role_description = RoleDescriptionSerializer(read_only=True,
         help_text=_("Description of the role"))
