@@ -50,6 +50,7 @@ from ..utils import get_organization_model
 class IncludesSyncErrorPagination(PageNumberPagination):
 
     def paginate_queryset(self, queryset, request, view=None):
+        #pylint:disable=attribute-defined-outside-init
         if view and hasattr(view, 'processor_error'):
             self.detail = view.processor_error
         return super(IncludesSyncErrorPagination, self).paginate_queryset(
@@ -216,7 +217,7 @@ class BillingsAPIView(SmartTransactionListMixin,
     and sorted on specific fields (``o``).
 
     The API is typically used within an HTML
-    `billing history page </docs/themes/#dashboard_billing_history>`_
+    `billing history page </docs/guides/themes/#dashboard_billing_history>`_
     as present in the default theme.
 
     **Tags**: billing, list, subscriber, transactionmodel
@@ -382,7 +383,7 @@ class TransferListAPIView(SmartTransactionListMixin, TransferQuerysetMixin,
     and sorted on specific fields (``o``).
 
     The API is typically used within an HTML
-    `funds page </docs/themes/#dashboard_billing_transfers>`_
+    `funds page </docs/guides/themes/#dashboard_billing_transfers>`_
     as present in the default theme.
 
     **Tags**: billing, list, provider, transactionmodel
