@@ -1,4 +1,4 @@
-# Copyright (c) 2021, DjaoDjin inc.
+# Copyright (c) 2022, DjaoDjin inc.
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -26,7 +26,7 @@
 The `Stripe <https://stripe.com/>`_ backend works in 3 different modes:
 
   - ``LOCAL``
-  - ``FORMWARD``
+  - ``FORWARD``
   - ``REMOTE``
 
 In LOCAL mode, Stripe Customer and Charge objects are created on the Stripe
@@ -69,12 +69,11 @@ from hashlib import sha512
 from base64 import b64encode
 
 from django.db import transaction
-from django.utils.translation import ugettext_lazy as _
-import requests, stripe
+import stripe
 
 from .. import CardError, ProcessorError, ProcessorSetupError
 from ... import settings, signals
-from ...compat import import_string, reverse, six
+from ...compat import (import_string, gettext_lazy as _, reverse, six)
 from ...utils import (datetime_to_utctimestamp, utctimestamp_to_datetime,
     datetime_or_now)
 
@@ -95,6 +94,8 @@ class StripeBackend(object):
         self.priv_key = settings.PROCESSOR['PRIV_KEY']
         self.client_id = settings.PROCESSOR.get('CLIENT_ID', None)
         self.mode = settings.PROCESSOR.get('MODE', self.LOCAL)
+        self.connect_callback_url = settings.PROCESSOR.get(
+            'CONNECT_CALLBACK_URL', None)
 
     def _get_processor_charge(self, stripe_charge_key, broker,
                               includes_fee=False):
@@ -182,6 +183,13 @@ class StripeBackend(object):
             result = (result and self.client_id)
         return result
 
+    def requires_provider_keys(self):
+        """
+        Returns `True` if Stripe requires a provider key along
+        with the StripeConnect keys.
+        """
+        return self.mode != self.LOCAL
+
     def list_customers(self, org_pat=r'.*', broker=None):
         """
         Returns a list of Stripe.Customer objects whose description field
@@ -293,29 +301,24 @@ class StripeBackend(object):
         organization.processor_deposit_key = None
         organization.processor_refresh_token = None
 
-        data = {'grant_type': 'authorization_code',
-                'client_secret': self.priv_key,
-                'code': code}
         if not settings.BYPASS_PROCESSOR_AUTH:
-            # Make /oauth/token endpoint POST request
-            # (XXX not available in stripe library code?)
-            resp = requests.post('https://connect.stripe.com/oauth/token',
-                params=data)
+            # Requires stripe version published after 2017
+            try:
+                self._prepare_request()
+                data = stripe.OAuth.token(
+                    grant_type='authorization_code',
+                    code=code)
+            except stripe.error.StripeError as err:
+                LOGGER.exception(err)
+                raise ProcessorError(str(err), backend_except=err)
         else:
             # Use mockup bogus data
-            resp = requests.Response()
-            resp.status_code = 200
-            #pylint:disable=protected-access
-            resp._content = '{"stripe_publishable_key": "123456789",'\
-                '"access_token": "123456789",'\
-                '"stripe_user_id": "123456789",'\
-                '"refresh_token": "123456789"}'.encode('utf-8')
-        # Grab access_token (use this as your user's API key)
-        data = resp.json()
-        if resp.status_code != 200:
-            LOGGER.debug("[connect_auth] error headers: %s", resp.headers)
-            raise ProcessorError(
-                message="%s: %s" % (data['error'], data['error_description']))
+            data = {
+                "stripe_publishable_key": "123456789",
+                "access_token": "123456789",
+                "stripe_user_id": "123456789",
+                "refresh_token": "123456789"
+            }
         LOGGER.debug("%s Stripe API returned: %s", organization, data)
         LOGGER.info("%s connect to Stripe authorized.", organization,
             extra={'event': 'connect-authorized', 'processor': 'stripe',
@@ -698,7 +701,7 @@ class StripeBackend(object):
         }
         authorize_url = "https://connect.stripe.com/oauth/authorize?response_type=code&client_id=%(client_id)s&scope=read_write&state=%(state)s" % data
         if not redirect_uri:
-            redirect_uri = settings.PROCESSOR_CONNECT_CALLBACK_URL
+            redirect_uri = self.connect_callback_url
         if redirect_uri:
             authorize_url += "&redirect_uri=%s" % redirect_uri
         return authorize_url
