@@ -1,4 +1,4 @@
-# Copyright (c) 2021, DjaoDjin inc.
+# Copyright (c) 2022, DjaoDjin inc.
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -26,17 +26,20 @@
 URLs to populate type-ahead candidate lists
 """
 
-from django.conf.urls import url
-
-from ...api.accounts import (AccountsTypeaheadAPIView, ProfilesTypeaheadAPIView,
-    UsersTypeaheadAPIView)
+from ... import settings
+from ...api.accounts import (AccountsTypeaheadAPIView, ProfileAPIView,
+    ProfilesTypeaheadAPIView, UsersTypeaheadAPIView)
+from ...compat import path
 
 
 urlpatterns = [
-    url(r'^accounts/$', AccountsTypeaheadAPIView.as_view(),
-        name='saas_api_search_accounts'),
-    url(r'^accounts/users/$', UsersTypeaheadAPIView.as_view(),
-        name='saas_api_search_users'),
-    url(r'^accounts/profiles/$', ProfilesTypeaheadAPIView.as_view(),
-        name='saas_api_search_profiles'),
+    path('accounts/users',
+        UsersTypeaheadAPIView.as_view(), name='saas_api_search_users'),
+    path('accounts/profiles/<slug:%s>' %
+        settings.PROFILE_URL_KWARG,
+        ProfileAPIView.as_view(), name='saas_api_search_profile'),
+    path('accounts/profiles',
+        ProfilesTypeaheadAPIView.as_view(), name='saas_api_search_profiles'),
+    path('accounts',
+        AccountsTypeaheadAPIView.as_view(), name='saas_api_search_accounts'),
 ]
